class Track:
    """"
    A track object summarize an activity
    
    init args :
        filepath : , 
        platform='garmin', 
        athlete='unknown', 
        activity_id='unknown' (platform id), 
        type='unkown' (activity type)
        
    attributes :
        points (dataframe)   : timestamp, lat, lon, ...
        features (dict) : global features
            ['activity_id', 'activity_name', 'activity_type', 'athlete', 'date',
            'device', 'distance', 'duration', 'elevationGain', 'has_po', 'has_tcx',
            'has_hr', 'startLatitude', 'startLongitude', 'startTimeGMT',
            'race_name', 'race_id', 'avHR', 'isarun',
            record_data  (device, platform, ...)
            
    methods :
        parse :
        get_google_elevation :
        get_speed :
        get_run_po :
        get_ta :
        
    """"
    def __init__(self, filepath='tcx_folder', platform='garmin', athlete='unknown', activity_id='unknown', type='unkown'):
        



__all__ = ['track', 'parsers','elevation','hr','processing']

from .track import Track
print('importing tracks')

def parse(filepath,platform='unknown',athlete='unknown',activityId='unknown'):
    return Track(filepath,platform,athlete,activityId)
    
  


from setuptools import setup

def readme():
    with open('README.md') as f:
        return f.read()

setup(name='analytracks',
      version='0.2.1.10',
      description='This python package contains tools to handle sport gps tracks (tcx, gpx, ...)',
#      long_description=readme(),
      url='http://www.olbecke.eu/research',
      author='Dimitri de Smet',
      author_email='dimitri.desmet@uclouvain.be',
      license='MIT',
      packages=['analytracks'],
      install_requires=['pandas'],
      package_data={'mypkg': ['data/*.dat']},
      zip_safe=True)
